@@ -58,13 +58,17 @@ def setHubzeroConfigOption(headerName, optionName, optionValue):
 		raise Exception("Cannot find hubzeroConfFileLocation:" + hubzeroConfFileLocation)
 
 	config = ConfigParser.ConfigParser()
-	config.readfp(open(hubzeroConfFileLocation))
 
-	if not config.has_section(headerName):
-		config.add_section(headerName)
+	with open(hubzeroConfFileLocation,"r+") as f:
+		config.readfp(f)
 
-	config.set(headerName, optionName, optionValue)
+		if not config.has_section(headerName):
+			config.add_section(headerName)
 
+		config.set(headerName, optionName, optionValue)
+		f.seek(0)
+		config.write(f)
+		f.truncate()
 
 def getHubDefaultSite():
 	return getHubzeroConfigOption("DEFAULT", "site")
