@@ -552,9 +552,19 @@ def getCMSversion(document_root = None):
 		default_site = hubzero.config.hubzerositeconfig.getHubDefaultSite()
 		document_root = hubzero.config.hubzerositeconfig.getHubzeroConfigOption(default_site, 'documentroot')
 
-	# 2.0.0 should actually look in core/libraries/Hubzero/Version/Version.php but the regex would be different
+	# 2.1.0 look in the vendor hubzero framework (this will change in 2.1.1)
+	if os.path.isfile(document_root + "/vendor/hubzero/framework/src/Version/Version.php"):
+		f = open(document_root + "/vendor/hubzero/framework/src/Version/Version.php", 'r')
+		file_text =  f.read()
+		p = re.compile(r"VERSION\s*=\s*['\"]+\s*(.*?)\s*['\"]+", re.MULTILINE)
+		m = p.search(file_text)
+		if not m:
+			return None
+		else:
+			return m.group(1)
 
-	if os.path.isfile(document_root + "/core//libraries/cms.php"):
+	# 2.0.0 should actually look in core/libraries/Hubzero/Version/Version.php but the regex would be different
+	if os.path.isfile(document_root + "/core/libraries/cms.php"):
 		f = open(document_root + "/core/libraries/cms.php", 'r')
 		file_text =  f.read()
 		p = re.compile(r"HVERSION['\"]+\s*,\s*['\"]+\s*(.*?)\s*['\"]+", re.MULTILINE)
@@ -563,6 +573,8 @@ def getCMSversion(document_root = None):
 			return None
 		else:
 			return m.group(1)
+
+	# 1.2.0,1.2.1,1.2.2,1.2.3,1.3.0,1.3.1
 	if os.path.isfile(document_root + "/libraries/cms.php"):
 		f = open(document_root + "/libraries/cms.php", 'r')
 		file_text =  f.read()
@@ -572,6 +584,7 @@ def getCMSversion(document_root = None):
 			return None
 		else:
 			return m.group(1)
+
 	elif os.path.isdir(document_root + "/libraries/Hubzero/Oauth"):
 		return "1.1.0"
 	elif os.path.isdir(document_root + "/libraries/Hubzero/Session"):
